@@ -2,7 +2,7 @@
 
 /*  CFL
  *  ===
- *  Copyright (C) 2022 The CFL Authors
+ *  Copyright (C) 2022-2024 The CFL Authors
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -88,9 +88,9 @@ int cfl_array_remove_by_index(struct cfl_array *array,
     cfl_variant_destroy(array->entries[position]);
 
     if (position != array->entry_count - 1) {
-        memcpy(&array->entries[position],
-               &array->entries[position + 1],
-               sizeof(void *) * (array->entry_count - (position + 1)));
+        memmove(&array->entries[position],
+                &array->entries[position + 1],
+                sizeof(void *) * (array->entry_count - (position + 1)));
     }
     else {
         array->entries[position] = NULL;
@@ -129,6 +129,15 @@ int cfl_array_append(struct cfl_array *array,
          * it controls the input data.
          */
         if (array->resizable) {
+
+            /*
+             * if the array size is zero (created as an array of 0 slots),
+             * change the size to 1 so the resize can work properly
+             */
+            if (array->slot_count == 0) {
+                array->slot_count = 1;
+            }
+
             /* set new number of slots and total size */
             new_slot_count = (array->slot_count * 2);
             new_size = (new_slot_count * sizeof(void *));
@@ -145,13 +154,17 @@ int cfl_array_append(struct cfl_array *array,
             return -1;
         }
     }
-    array->entries[array->entry_count++] = value;
 
+    /* this is just a double check to make sure the slot is really available */
+    if (array->entry_count >= array->slot_count) {
+        return -1;
+    }
+
+    array->entries[array->entry_count++] = value;
     return 0;
 }
 
-int cfl_array_append_string(struct cfl_array *array,
-                            char *value)
+int cfl_array_append_string(struct cfl_array *array, char *value)
 {
     struct cfl_variant *value_instance;
     int                 result;
@@ -165,7 +178,25 @@ int cfl_array_append_string(struct cfl_array *array,
     result = cfl_array_append(array, value_instance);
     if (result) {
         cfl_variant_destroy(value_instance);
+        return -2;
+    }
 
+    return 0;
+}
+
+int cfl_array_append_string_s(struct cfl_array *array, char *str, size_t str_len, int referenced)
+{
+    struct cfl_variant *value_instance;
+    int                 result;
+
+    value_instance = cfl_variant_create_from_string_s(str, str_len, referenced);
+    if (value_instance == NULL) {
+        return -1;
+    }
+
+    result = cfl_array_append(array, value_instance);
+    if (result) {
+        cfl_variant_destroy(value_instance);
         return -2;
     }
 
@@ -174,13 +205,13 @@ int cfl_array_append_string(struct cfl_array *array,
 
 int cfl_array_append_bytes(struct cfl_array *array,
                            char *value,
-                           size_t length)
+                           size_t length,
+                           int referenced)
 {
     struct cfl_variant *value_instance;
     int                 result;
 
-    value_instance = cfl_variant_create_from_bytes(value, length);
-
+    value_instance = cfl_variant_create_from_bytes(value, length, referenced);
     if (value_instance == NULL) {
         return -1;
     }
@@ -305,6 +336,24 @@ int cfl_array_append_double(struct cfl_array *array, double value)
     return 0;
 }
 
+int cfl_array_append_null(struct cfl_array *array)
+{
+    struct cfl_variant *value_instance;
+    int                 result;
+
+    value_instance = cfl_variant_create_from_null();
+    if (value_instance == NULL) {
+        return -1;
+    }
+
+    result = cfl_array_append(array, value_instance);
+    if (result) {
+        cfl_variant_destroy(value_instance);
+        return -2;
+    }
+
+    return 0;
+}
 
 int cfl_array_append_array(struct cfl_array *array, struct cfl_array *value)
 {
@@ -347,8 +396,7 @@ int cfl_array_append_new_array(struct cfl_array *array, size_t size)
     return result;
 }
 
-int cfl_array_append_kvlist(struct cfl_array *array, struct 
-cfl_kvlist *value)
+int cfl_array_append_kvlist(struct cfl_array *array, struct cfl_kvlist *value)
 {
     struct cfl_variant *value_instance;
     int                 result;
