@@ -20,6 +20,9 @@
 #include <ctraces/ctraces.h>
 #include <fluent-otel-proto/fluent-otel.h>
 
+static void destroy_scope_spans(Opentelemetry__Proto__Trace__V1__ScopeSpans **scope_spans,
+                         size_t count);
+
 static inline Opentelemetry__Proto__Common__V1__AnyValue *ctr_variant_to_otlp_any_value(struct cfl_variant *value);
 static inline Opentelemetry__Proto__Common__V1__KeyValue *ctr_variant_kvpair_to_otlp_kvpair(struct cfl_kvpair *input_pair);
 static inline Opentelemetry__Proto__Common__V1__AnyValue *ctr_variant_kvlist_to_otlp_any_value(struct cfl_variant *value);
@@ -914,11 +917,21 @@ static Opentelemetry__Proto__Common__V1__InstrumentationScope *set_instrumentati
         return NULL;
     }
 
-    otel_scope->name = instrumentation_scope->name;
-    otel_scope->version = instrumentation_scope->version;
+    if (instrumentation_scope->name) {
+        otel_scope->name = instrumentation_scope->name;
+    }
+    else {
+        otel_scope->name = "";
+    }
+    if (instrumentation_scope->version) {
+        otel_scope->version = instrumentation_scope->version;
+    }
+    else {
+        otel_scope->version = "";
+    }
     otel_scope->n_attributes = get_attributes_count(instrumentation_scope->attr);
     otel_scope->dropped_attributes_count = instrumentation_scope->dropped_attr_count;
-    otel_scope->attributes = set_attributes_from_ctr(instrumentation_scope->attr);;
+    otel_scope->attributes = set_attributes_from_ctr(instrumentation_scope->attr);
 
     return otel_scope;
 }
@@ -976,11 +989,19 @@ static Opentelemetry__Proto__Trace__V1__ScopeSpans **set_scope_spans(struct ctra
 
         otel_scope_span = initialize_scope_span();
         if (!otel_scope_span) {
+            if (scope_span_index > 0) {
+                destroy_scope_spans(scope_spans, scope_span_index - 1);
+            }
+
+            free(scope_spans);
+
             return NULL;
         }
 
         otel_scope_span->schema_url = scope_span->schema_url;
-        otel_scope_span->scope = set_instrumentation_scope(scope_span->instrumentation_scope);
+        if (scope_span->instrumentation_scope != NULL) {
+            otel_scope_span->scope = set_instrumentation_scope(scope_span->instrumentation_scope);
+        }
 
         span_count = cfl_list_size(&scope_span->spans);
         otel_scope_span->n_spans = span_count;
