@@ -28,14 +28,27 @@
 #include <mk_core/mk_utils.h>
 #include <mk_core/mk_event.h>
 
-#if defined(_WIN32)
-    #include "mk_event_libevent.c"
-#elif defined(MK_HAVE_EVENT_SELECT)
+#if defined(MK_EVENT_LOOP_SELECT)
     #include "mk_event_select.c"
-#elif defined(__linux__) && !defined(LINUX_KQUEUE)
-    #include "mk_event_epoll.c"
-#else
+#elif defined(MK_EVENT_LOOP_POLL)
+    #include "mk_event_poll.c"
+#elif defined(MK_EVENT_LOOP_KQUEUE)
     #include "mk_event_kqueue.c"
+#elif defined(MK_EVENT_LOOP_EPOLL)
+    #include "mk_event_epoll.c"
+#elif defined(MK_EVENT_LOOP_LIBEVENT)
+    #include "mk_event_libevent.c"
+#else
+    /* do our best based on the operating system */
+    #if defined(__linux__)
+        #include "mk_event_epoll.c"
+    #elif defined(__FreeBSD__) || defined(__APPLE__) || defined(__DragonFly__) || defined(__OpenBSD__)
+        #include "mk_event_kqueue.c"
+    #elif defined(_WIN32)
+        #include "mk_event_libevent.c"
+    #else
+        #include "mk_event_select.c"
+    #endif
 #endif
 
 /* Initialize backend */
@@ -106,8 +119,6 @@ int mk_event_add(struct mk_event_loop *loop, int fd,
 int mk_event_inject(struct mk_event_loop *loop, struct mk_event *event,
                     int flags, int prevent_duplication)
 {
-    int result;
-
     if (loop->n_events + 1 >= loop->size) {
         return -1;
     }
@@ -178,10 +189,32 @@ int mk_event_channel_create(struct mk_event_loop *loop,
     return _mk_event_channel_create(ctx, r_fd, w_fd, data);
 }
 
+/* Destroy channel created to distribute signals */
+int mk_event_channel_destroy(struct mk_event_loop *loop,
+                            int r_fd, int w_fd,
+                            void *data)
+{
+    struct mk_event_ctx *ctx;
+
+    mk_bug(!data);
+    ctx = loop->data;
+    return _mk_event_channel_destroy(ctx, r_fd, w_fd, data);
+}
+
 /* Poll events */
 int mk_event_wait(struct mk_event_loop *loop)
 {
-    return _mk_event_wait(loop);
+    return _mk_event_wait_2(loop, -1);
+}
+
+/*
+ * Poll events with timeout in milliseconds
+ * zero timeout for non blocking wait
+ * -1 timeout for infinite wait
+ */
+int mk_event_wait_2(struct mk_event_loop *loop, int timeout)
+{
+    return _mk_event_wait_2(loop, timeout);
 }
 
 /* Return the backend name */
