@@ -110,7 +110,8 @@ static int in_collectd_init(struct flb_input_instance *in,
     /* Set the context */
     flb_input_set_context(in, ctx);
 
-    ctx->server_fd = flb_net_server_udp(ctx->port, ctx->listen);
+    ctx->server_fd = flb_net_server_udp(ctx->port, ctx->listen, 
+                                        in->net_setup.share_port);
     if (ctx->server_fd < 0) {
         flb_plg_error(ctx->ins, "failed to bind to %s:%s", ctx->listen,
                       ctx->port);
