@@ -2,8 +2,7 @@
 
 /*  Fluent Bit
  *  ==========
- *  Copyright (C) 2019-2021 The Fluent Bit Authors
- *  Copyright (C) 2015-2018 Treasure Data Inc.
+ *  Copyright (C) 2015-2024 The Fluent Bit Authors
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -20,4 +19,4 @@
 
 /* Convert a binary buffer into MessagePack format */
 int netprot_to_msgpack(char *buf, int len, struct mk_list *tdb,
-                       msgpack_packer *ppck);
+                       struct flb_log_event_encoder *encoder);
