@@ -620,6 +620,7 @@ static int check_ping(struct flb_input_instance *ins,
     if (o.type != MSGPACK_OBJECT_STR) {
         flb_plg_error(ins, "Invalid username type message");
         flb_free(serverside);
+        flb_free(hostname);
         msgpack_unpacked_destroy(&result);
         return -1;
     }
@@ -631,6 +632,8 @@ static int check_ping(struct flb_input_instance *ins,
         flb_plg_error(ins, "Invalid password_digest type message");
         flb_free(serverside);
         flb_free(hostname);
+        flb_free(shared_key_salt);
+        flb_free(shared_key_digest);
         msgpack_unpacked_destroy(&result);
         return -1;
     }
@@ -643,6 +646,8 @@ static int check_ping(struct flb_input_instance *ins,
                                            shared_key_salt, hostname, hostname_len,
                                            serverside, 128)) {
         flb_free(serverside);
+        flb_free(username);
+        flb_free(password_digest);
         flb_plg_error(ctx->ins, "failed to hash shard_key");
         return -1;
     }
@@ -1122,6 +1127,7 @@ static int append_log(struct flb_input_instance *ins, struct fw_conn *conn,
         flb_input_metrics_append(conn->in,
                                  out_tag, flb_sds_len(out_tag),
                                  cmt);
+        cmt_decode_msgpack_destroy(cmt);
     }
     else if (event_type == FLB_EVENT_TYPE_TRACES) {
         off = 0;
@@ -1133,6 +1139,8 @@ static int append_log(struct flb_input_instance *ins, struct fw_conn *conn,
         flb_input_trace_append(ins,
                                out_tag, flb_sds_len(out_tag),
                                ctr);
+
+        ctr_decode_msgpack_destroy(ctr);
     }
 
     return 0;
