@@ -20,10 +20,15 @@
 #ifndef FLB_IN_HTTP_PROT
 #define FLB_IN_HTTP_PROT
 
+#include <fluent-bit/flb_http_common.h>
+
 int http_prot_handle(struct flb_http *ctx, struct http_conn *conn,
                      struct mk_http_session *session,
                      struct mk_http_request *request);
 
+int http_prot_handle_ng(struct flb_http_request *request,
+                        struct flb_http_response *response);
+
 int http_prot_handle_error(struct flb_http *ctx, struct http_conn *conn,
                            struct mk_http_session *session,
                            struct mk_http_request *request);
