@@ -459,7 +459,7 @@ static int ne_systemd_update_unit_state(struct flb_ne *ctx)
             }
 
             for(index = 0 ; index < 5 ; index++) {
-                cmt_gauge_add(ctx->systemd_unit_state,
+                cmt_gauge_set(ctx->systemd_unit_state,
                               timestamp,
                               0,
                               3,
@@ -469,8 +469,9 @@ static int ne_systemd_update_unit_state(struct flb_ne *ctx)
                                         });
             }
 
-            cmt_gauge_inc(ctx->systemd_unit_state,
+            cmt_gauge_set(ctx->systemd_unit_state,
                           timestamp,
+                          1,
                           3,
                           (char *[]){ unit.name,
                                       unit.active_state,
