@@ -2,8 +2,7 @@
 
 /*  Fluent Bit
  *  ==========
- *  Copyright (C) 2019-2021 The Fluent Bit Authors
- *  Copyright (C) 2015-2018 Treasure Data Inc.
+ *  Copyright (C) 2015-2024 The Fluent Bit Authors
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -18,12 +17,13 @@
  *  limitations under the License.
  */
 
+#include <fluent-bit/flb_output.h>
 #include <fluent-bit/flb_input_plugin.h>
 #include <fluent-bit/flb_input_chunk.h>
-#include <fluent-bit/flb_output.h>
 #include <fluent-bit/flb_storage.h>
 #include <fluent-bit/flb_utils.h>
 #include <chunkio/chunkio.h>
+#include <chunkio/cio_error.h>
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -91,7 +91,7 @@ static int sb_append_chunk_to_segregated_backlogs(struct cio_chunk  *target_chun
 int sb_segregate_chunks(struct flb_config *config);
 
 int sb_release_output_queue_space(struct flb_output_instance *output_plugin,
-                                  size_t                      required_space);
+                                  ssize_t                    *required_space);
 
 ssize_t sb_get_releasable_output_queue_space(struct flb_output_instance *output_plugin,
                                              size_t                      required_space);
@@ -256,7 +256,6 @@ static int sb_append_chunk_to_segregated_backlog(struct cio_chunk    *target_chu
     struct sb_out_chunk *chunk;
 
     chunk = sb_allocate_chunk(target_chunk, stream, target_chunk_size);
-
     if (chunk == NULL) {
         flb_errno();
         return -1;
@@ -274,7 +273,8 @@ static int sb_append_chunk_to_segregated_backlogs(struct cio_chunk  *target_chun
                                                   struct flb_sb     *context)
 {
     struct flb_input_chunk  dummy_input_chunk;
-    struct mk_list         *backlog_iterator;
+    struct mk_list         *tmp;
+    struct mk_list         *head;
     size_t                  chunk_size;
     struct sb_out_queue    *backlog;
     int                     tag_len;
@@ -289,25 +289,24 @@ static int sb_append_chunk_to_segregated_backlogs(struct cio_chunk  *target_chun
     chunk_size = cio_chunk_get_real_size(target_chunk);
 
     if (chunk_size < 0) {
-        flb_warn("[storage backlog] could not retrieve chunk real size");
-
+        flb_warn("[storage backlog] could not get real size of chunk %s/%s",
+                  stream->name, target_chunk->name);
         return -1;
     }
 
     result = flb_input_chunk_get_tag(&dummy_input_chunk, &tag_buf, &tag_len);
-
     if (result == -1) {
-        flb_error("[storage backlog] could not retrieve chunk tag");
-
+        flb_error("[storage backlog] could not retrieve chunk tag from %s/%s, "
+                  "removing it from the queue",
+                  stream->name, target_chunk->name);
         return -2;
     }
 
     flb_routes_mask_set_by_tag(dummy_input_chunk.routes_mask, tag_buf, tag_len,
                                context->ins);
 
-    mk_list_foreach(backlog_iterator, &context->backlogs) {
-        backlog = mk_list_entry(backlog_iterator, struct sb_out_queue, _head);
-
+    mk_list_foreach_safe(head, tmp, &context->backlogs) {
+        backlog = mk_list_entry(head, struct sb_out_queue, _head);
         if (flb_routes_mask_get_bit(dummy_input_chunk.routes_mask,
                                     backlog->ins->id)) {
             result = sb_append_chunk_to_segregated_backlog(target_chunk, stream,
@@ -323,10 +322,13 @@ static int sb_append_chunk_to_segregated_backlogs(struct cio_chunk  *target_chun
 
 int sb_segregate_chunks(struct flb_config *config)
 {
+    int                ret;
+    size_t             size;
+    struct mk_list    *tmp;
     struct mk_list    *stream_iterator;
     struct mk_list    *chunk_iterator;
+    int                chunk_error;
     struct flb_sb     *context;
-    int                result;
     struct cio_stream *stream;
     struct cio_chunk  *chunk;
 
@@ -336,31 +338,66 @@ int sb_segregate_chunks(struct flb_config *config)
         return 0;
     }
 
-    result = sb_allocate_backlogs(context);
-
-    if (result) {
+    ret = sb_allocate_backlogs(context);
+    if (ret) {
         return -2;
     }
 
     mk_list_foreach(stream_iterator, &context->cio->streams) {
         stream = mk_list_entry(stream_iterator, struct cio_stream, _head);
 
-        mk_list_foreach(chunk_iterator, &stream->chunks) {
+        mk_list_foreach_safe(chunk_iterator, tmp, &stream->chunks) {
             chunk = mk_list_entry(chunk_iterator, struct cio_chunk, _head);
 
             if (!cio_chunk_is_up(chunk)) {
-                cio_chunk_up_force(chunk);
+                ret = cio_chunk_up_force(chunk);
+                if (ret == CIO_CORRUPTED) {
+                    if (config->storage_del_bad_chunks) {
+                        chunk_error = cio_error_get(chunk);
+
+                        if (chunk_error == CIO_ERR_BAD_FILE_SIZE ||
+                            chunk_error == CIO_ERR_BAD_LAYOUT)
+                        {
+                            flb_plg_error(context->ins, "discarding irrecoverable chunk %s/%s", stream->name, chunk->name);
+
+                            cio_chunk_close(chunk, CIO_TRUE);
+                        }
+                    }
+
+                    continue;
+                }
             }
 
             if (!cio_chunk_is_up(chunk)) {
                 return -3;
             }
 
-            result = sb_append_chunk_to_segregated_backlogs(chunk, stream, context);
+            /* try to segregate a chunk */
+            ret = sb_append_chunk_to_segregated_backlogs(chunk, stream, context);
+            if (ret) {
+                /*
+                 * if the chunk could not be segregated, just remove it from the
+                 * queue, delete it and continue.
+                 */
 
-            if (result) {
-                flb_error("[storage backlog] error distributing chunk references");
-                return -4;
+                /* If the tag cannot be read it cannot be routed, let's remove it */
+                if (ret == -2) {
+                    cio_chunk_close(chunk, CIO_TRUE);
+                    continue;
+                }
+
+                /* 
+                 *
+                 * if content size is zero, it's safe to 'delete it'.
+                 */
+                size = cio_chunk_get_content_size(chunk);
+                if (size <= 0) {
+                    cio_chunk_close(chunk, CIO_TRUE);
+                }
+                else {
+                    cio_chunk_close(chunk, CIO_FALSE);
+                }
+                continue;
             }
 
             /* lock the chunk */
@@ -412,13 +449,12 @@ ssize_t sb_get_releasable_output_queue_space(struct flb_output_instance *output_
 }
 
 int sb_release_output_queue_space(struct flb_output_instance *output_plugin,
-                                  size_t                      required_space)
+                                  ssize_t                    *required_space)
 {
     struct mk_list      *chunk_iterator_tmp;
-    size_t               releasable_space;
+    struct cio_chunk    *underlying_chunk;
     struct mk_list      *chunk_iterator;
     size_t               released_space;
-    size_t               chunk_size;
     struct flb_sb       *context;
     struct sb_out_queue *backlog;
     struct sb_out_chunk *chunk;
@@ -442,18 +478,17 @@ int sb_release_output_queue_space(struct flb_output_instance *output_plugin,
         chunk = mk_list_entry(chunk_iterator, struct sb_out_chunk, _head);
 
         released_space += chunk->size;
+        underlying_chunk = chunk->chunk;
 
-        cio_chunk_close(chunk->chunk, FLB_TRUE);
-        sb_remove_chunk_from_segregated_backlogs(chunk->chunk, context);
+        sb_remove_chunk_from_segregated_backlogs(underlying_chunk, context);
+        cio_chunk_close(underlying_chunk, FLB_TRUE);
 
-        if (released_space >= required_space) {
+        if (released_space >= *required_space) {
             break;
         }
     }
 
-    if (released_space < required_space) {
-        return -3;
-    }
+    *required_space -= released_space;
 
     return 0;
 }
@@ -468,10 +503,12 @@ static int cb_queue_chunks(struct flb_input_instance *in,
     struct sb_out_chunk    *chunk_instance;
     struct flb_sb          *ctx;
     struct flb_input_chunk *ic;
+    struct flb_input_chunk  tmp_ic;
     void                   *ch;
     size_t                  total = 0;
     ssize_t                 size;
     int                     ret;
+    int                     event_type;
 
     /* Get context */
     ctx = (struct flb_sb *) data;
@@ -526,6 +563,27 @@ static int cb_queue_chunks(struct flb_input_instance *in,
                     }
                 }
 
+                /*
+                 * Map the chunk file context into a temporary buffer since the
+                 * flb_input_chunk_get_event_type() interface needs an
+                 * struct fb_input_chunk argument.
+                 */
+                tmp_ic.chunk = chunk_instance->chunk;
+
+                /* Retrieve the event type: FLB_INPUT_LOGS, FLB_INPUT_METRICS of FLB_INPUT_TRACES */
+                ret = flb_input_chunk_get_event_type(&tmp_ic);
+                if (ret == -1) {
+                    flb_plg_error(ctx->ins, "removing chunk with wrong metadata "
+                                  "from the queue %s:%s",
+                                  chunk_instance->stream->name,
+                                  chunk_instance->chunk->name);
+                    cio_chunk_close(chunk_instance->chunk, FLB_TRUE);
+                    sb_remove_chunk_from_segregated_backlogs(chunk_instance->chunk,
+                                                             ctx);
+                    continue;
+                }
+                event_type = ret;
+
                 /* get the number of bytes being used by the chunk */
                 size = cio_chunk_get_content_size(chunk_instance->chunk);
                 if (size <= 0) {
@@ -543,7 +601,7 @@ static int cb_queue_chunks(struct flb_input_instance *in,
                 ch = chunk_instance->chunk;
 
                 /* Associate this backlog chunk to this instance into the engine */
-                ic = flb_input_chunk_map(in, ch);
+                ic = flb_input_chunk_map(in, event_type, ch);
                 if (!ic) {
                     flb_plg_error(ctx->ins, "removing chunk %s:%s from the queue",
                                   chunk_instance->stream->name, chunk_instance->chunk->name);
@@ -568,6 +626,7 @@ static int cb_queue_chunks(struct flb_input_instance *in,
                  * queue but we need to leave it in the remainder queues.
                  */
                 sb_remove_chunk_from_segregated_backlogs(chunk_instance->chunk, ctx);
+                cio_chunk_down(ch);
 
                 /* check our limits */
                 total += size;
