@@ -2,8 +2,7 @@
 
 /*  Fluent Bit
  *  ==========
- *  Copyright (C) 2019-2021 The Fluent Bit Authors
- *  Copyright (C) 2015-2018 Treasure Data Inc.
+ *  Copyright (C) 2015-2024 The Fluent Bit Authors
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -25,19 +24,37 @@
 #include <fluent-bit/flb_sds.h>
 #include <fluent-bit/flb_upstream_ha.h>
 #include <fluent-bit/flb_record_accessor.h>
+#include <fluent-bit/flb_connection.h>
+#include <fluent-bit/flb_pthread.h>
+#include <cfl/cfl_list.h>
 
-#ifdef FLB_HAVE_TLS
-#include <mbedtls/entropy.h>
-#include <mbedtls/error.h>
-#include <mbedtls/ctr_drbg.h>
-#endif
+/*
+ * Forward modes
+ * =============
+ */
 
-/* Forward modes */
+/*
+ * Message mode
+ * ------------
+ * https://github.com/fluent/fluentd/wiki/Forward-Protocol-Specification-v1#message-modes
+ */
 #define MODE_MESSAGE               0
+
+/*
+ * Forward mode
+ * ------------
+ * https://github.com/fluent/fluentd/wiki/Forward-Protocol-Specification-v1#forward-mode
+ */
 #define MODE_FORWARD               1
+
+/*
+ * Forward Compat: similar to MODE_FORWARD, but it sends the timestamps as unsigned
+ * integers for compatibility with very old versions of Fluentd that don't have timestamps
+ * with nanoseconds. This mode only applies for Logs.
+ */
 #define MODE_FORWARD_COMPAT        3
 
-/* Compression modes */
+/* Compression options */
 #define COMPRESS_NONE              0
 #define COMPRESS_GZIP              1
 
@@ -54,6 +71,13 @@ struct flb_forward_config {
     int secured;              /* Using Secure Forward mode ?  */
     int compress;             /* Using compression ? */
     int time_as_integer;      /* Use backward compatible timestamp ? */
+    int fluentd_compat;       /* Use Fluentd compatible payload for
+                               * metrics and ctraces */
+
+    /* add extra options to the Forward payload (advanced) */
+    struct mk_list *extra_options;
+
+    int fwd_retain_metadata;  /* Do not drop metadata in forward mode */
 
     /* config */
     flb_sds_t shared_key;        /* shared key                   */
@@ -62,25 +86,30 @@ struct flb_forward_config {
     int empty_shared_key;        /* use an empty string as shared key */
     int require_ack_response;    /* Require acknowledge for "chunk" */
     int send_options;            /* send options in messages */
+    flb_sds_t unix_path;         /* unix socket path */
+    int       unix_fd;
 
     const char *username;
     const char *password;
 
     /* mbedTLS specifics */
     unsigned char shared_key_salt[16];
-#ifdef FLB_HAVE_TLS
-    mbedtls_entropy_context tls_entropy;
-    mbedtls_ctr_drbg_context tls_ctr_drbg;
-#endif
 
 #ifdef FLB_HAVE_RECORD_ACCESSOR
     struct flb_record_accessor *ra_tag; /* Tag Record accessor */
     int ra_static;                      /* Is the record accessor static ? */
 #endif
-
+    int (*io_write)(struct flb_connection* conn, int fd, const void* data,
+                        size_t len, size_t *out_len);
+    int (*io_read)(struct flb_connection* conn, int fd, void* buf, size_t len);
     struct mk_list _head;     /* Link to list flb_forward->configs */
 };
 
+struct flb_forward_uds_connection {
+    flb_sockfd_t    descriptor;
+    struct cfl_list _head;     /* Link to list flb_forward->uds_connnection_list */
+};
+
 /* Plugin Context */
 struct flb_forward {
     /* if HA mode is enabled */
@@ -88,6 +117,9 @@ struct flb_forward {
     char *ha_upstream;        /* Upstream configuration file      */
     struct flb_upstream_ha *ha;
 
+    struct cfl_list uds_connection_list;
+    pthread_mutex_t uds_connection_list_mutex;
+
     /* Upstream handler and config context for single mode (no HA) */
     struct flb_upstream *u;
     struct mk_list configs;
