@@ -2,8 +2,7 @@
 
 /*  Fluent Bit
  *  ==========
- *  Copyright (C) 2019-2021 The Fluent Bit Authors
- *  Copyright (C) 2015-2018 Treasure Data Inc.
+ *  Copyright (C) 2015-2024 The Fluent Bit Authors
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -40,8 +39,8 @@ static int cb_retry_init(struct flb_output_instance *ins,
 {
     (void) config;
     (void) data;
-    const char *tmp;
     struct retry_ctx *ctx;
+    int ret;
 
     ctx = flb_calloc(1, sizeof(struct retry_ctx));
     if (!ctx) {
@@ -50,28 +49,22 @@ static int cb_retry_init(struct flb_output_instance *ins,
     ctx->ins = ins;
     ctx->count = 0;
 
-    tmp = flb_output_get_property("retries", ins);
-    if (!tmp) {
-        ctx->n_retry = 3;
-    }
-    else {
-        ctx->n_retry = atoi(tmp);
+    ret = flb_output_config_map_set(ins, ctx);
+    if (ret == -1) {
+        flb_plg_error(ins, "unable to load configuration");
+        return -1;
     }
 
     flb_output_set_context(ins, ctx);
     return 0;
 }
 
-static void cb_retry_flush(const void *data, size_t bytes,
-                           const char *tag, int tag_len,
+static void cb_retry_flush(struct flb_event_chunk *event_chunk,
+                           struct flb_output_flush *out_flush,
                            struct flb_input_instance *i_ins,
                            void *out_context,
                            struct flb_config *config)
 {
-    (void) data;
-    (void) bytes;
-    (void) tag;
-    (void) tag_len;
     (void) i_ins;
     (void) out_context;
     (void) config;
@@ -89,7 +82,7 @@ static void cb_retry_flush(const void *data, size_t bytes,
         ctx->count = 0;
     }
 
-    flb_pack_print(data, bytes);
+    flb_pack_print(event_chunk->data, event_chunk->size);
     FLB_OUTPUT_RETURN(FLB_OK);
 }
 
@@ -102,11 +95,22 @@ static int cb_retry_exit(void *data, struct flb_config *config)
     return 0;
 }
 
+/* Configuration properties map */
+static struct flb_config_map config_map[] = {
+   {
+    FLB_CONFIG_MAP_INT, "retry", "3",
+    0, FLB_TRUE, offsetof(struct retry_ctx, n_retry),
+    "Number of retries."
+   },
+   {0}
+};
+
 struct flb_output_plugin out_retry_plugin = {
     .name         = "retry",
     .description  = "Issue a retry upon flush request",
     .cb_init      = cb_retry_init,
     .cb_flush     = cb_retry_flush,
     .cb_exit      = cb_retry_exit,
+    .config_map   = config_map,
     .flags        = 0,
 };
