@@ -2,8 +2,7 @@
 
 /*  Fluent Bit
  *  ==========
- *  Copyright (C) 2019-2021 The Fluent Bit Authors
- *  Copyright (C) 2015-2018 Treasure Data Inc.
+ *  Copyright (C) 2015-2024 The Fluent Bit Authors
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -23,10 +22,16 @@
 #include <fluent-bit/flb_mem.h>
 #include <fluent-bit/flb_log.h>
 #include <fluent-bit/flb_error.h>
+#include <fluent-bit/flb_kv.h>
+#include <fluent-bit/flb_config_format.h>
 #include <fluent-bit/flb_utils.h>
 #include <fluent-bit/flb_plugin.h>
 #include <fluent-bit/flb_plugin_proxy.h>
 
+#include <cfl/cfl_sds.h>
+#include <cfl/cfl_variant.h>
+#include <cfl/cfl_kvlist.h>
+
 #include <sys/types.h>
 #include <sys/stat.h>
 
@@ -54,6 +59,15 @@ static int is_filter(char *name)
     return FLB_FALSE;
 }
 
+static int is_processor(char *name)
+{
+    if (strncmp(name, "processor_", 10) == 0) {
+        return FLB_TRUE;
+    }
+
+    return FLB_FALSE;
+}
+
 static int is_output(char *name)
 {
     if (strncmp(name, "out_", 4) == 0) {
@@ -139,6 +153,7 @@ static char *path_to_plugin_name(char *path)
 
     /* Validate expected plugin type */
     if (is_input(name) == FLB_FALSE &&
+        is_processor(name) == FLB_FALSE &&
         is_filter(name) == FLB_FALSE &&
         is_output(name) == FLB_FALSE) {
         flb_error("[plugin] invalid plugin type: %s", name);
@@ -175,6 +190,7 @@ struct flb_plugins *flb_plugin_create()
     }
 
     mk_list_init(&ctx->input);
+    mk_list_init(&ctx->processor);
     mk_list_init(&ctx->filter);
     mk_list_init(&ctx->output);
 
@@ -190,6 +206,7 @@ int flb_plugin_load(char *path, struct flb_plugins *ctx,
     char *plugin_stname;
     struct flb_plugin *plugin;
     struct flb_input_plugin *input;
+    struct flb_processor_plugin *processor;
     struct flb_filter_plugin *filter;
     struct flb_output_plugin *output;
 
@@ -233,6 +250,18 @@ int flb_plugin_load(char *path, struct flb_plugins *ctx,
         memcpy(input, symbol, sizeof(struct flb_input_plugin));
         mk_list_add(&input->_head, &config->in_plugins);
     }
+    else if (is_processor(plugin_stname) == FLB_TRUE) {
+        type = FLB_PLUGIN_PROCESSOR;
+        processor = flb_malloc(sizeof(struct flb_processor_plugin));
+        if (processor == NULL) {
+            flb_errno();
+            flb_free(plugin_stname);
+            dlclose(dso_handle);
+            return -1;
+        }
+        memcpy(processor, symbol, sizeof(struct flb_processor_plugin));
+        mk_list_add(&processor->_head, &config->processor_plugins);
+    }
     else if (is_filter(plugin_stname) == FLB_TRUE) {
         type = FLB_PLUGIN_FILTER;
         filter = flb_malloc(sizeof(struct flb_filter_plugin));
@@ -281,6 +310,9 @@ int flb_plugin_load(char *path, struct flb_plugins *ctx,
     if (type == FLB_PLUGIN_INPUT) {
         mk_list_add(&plugin->_head, &ctx->input);
     }
+    else if (type == FLB_PLUGIN_PROCESSOR) {
+        mk_list_add(&plugin->_head, &ctx->processor);
+    }
     else if (type == FLB_PLUGIN_FILTER) {
         mk_list_add(&plugin->_head, &ctx->filter);
     }
@@ -326,13 +358,13 @@ int flb_plugin_load_config_file(const char *file, struct flb_config *config)
 {
     int ret;
     char tmp[PATH_MAX + 1];
-    const char *cfg = NULL;
-    struct mk_rconf *fconf;
-    struct mk_rconf_section *section;
-    struct mk_rconf_entry *entry;
+    char *cfg = NULL;
     struct mk_list *head;
-    struct mk_list *head_e;
+    struct cfl_list *head_e;
     struct stat st;
+    struct flb_cf *cf;
+    struct flb_cf_section *section;
+    struct cfl_kvpair *entry;
 
 #ifndef FLB_HAVE_STATIC_CONF
     ret = stat(file, &st);
@@ -349,42 +381,43 @@ int flb_plugin_load_config_file(const char *file, struct flb_config *config)
         }
     }
     else {
-        cfg = file;
+        cfg = (char *) file;
     }
 
     flb_debug("[plugin] opening configuration file %s", cfg);
-    fconf = mk_rconf_open(cfg);
+
+    cf = flb_cf_create_from_file(NULL, cfg);
 #else
-    fconf = flb_config_static_open(file);
+    cf = flb_config_static_open(file);
 #endif
 
-    if (!fconf) {
+    if (!cf) {
         return -1;
     }
 
-    /* Read all [PLUGINS] sections */
-    mk_list_foreach(head, &fconf->sections) {
-        section = mk_list_entry(head, struct mk_rconf_section, _head);
-        if (strcasecmp(section->name, "PLUGINS") != 0) {
+    /* read all 'plugins' sections */
+    mk_list_foreach(head, &cf->sections) {
+        section = mk_list_entry(head, struct flb_cf_section, _head);
+        if (strcasecmp(section->name, "plugins") != 0) {
             continue;
         }
 
-        mk_list_foreach(head_e, &section->entries) {
-            entry = mk_list_entry(head_e, struct mk_rconf_entry, _head);
-            if (strcmp(entry->key, "Path") != 0) {
+        cfl_list_foreach(head_e, &section->properties->list) {
+            entry = cfl_list_entry(head_e, struct cfl_kvpair, _head);
+            if (strcasecmp(entry->key, "path") != 0) {
                 continue;
             }
 
             /* Load plugin with router function */
-            ret = flb_plugin_load_router(entry->val, config);
+            ret = flb_plugin_load_router(entry->val->data.as_string, config);
             if (ret == -1) {
-                mk_rconf_free(fconf);
+                flb_cf_destroy(cf);
                 return -1;
             }
         }
     }
 
-    mk_rconf_free(fconf);
+    flb_cf_destroy(cf);
     return 0;
 }
 
@@ -400,6 +433,11 @@ void flb_plugin_destroy(struct flb_plugins *ctx)
         destroy_plugin(plugin);
     }
 
+    mk_list_foreach_safe(head, tmp, &ctx->processor) {
+        plugin = mk_list_entry(head, struct flb_plugin, _head);
+        destroy_plugin(plugin);
+    }
+
     mk_list_foreach_safe(head, tmp, &ctx->filter) {
         plugin = mk_list_entry(head, struct flb_plugin, _head);
         destroy_plugin(plugin);
