@@ -25,6 +25,7 @@
 #include <openssl/ssl.h>
 #include <openssl/err.h>
 #include <openssl/opensslv.h>
+#include <openssl/x509v3.h>
 
 #ifdef FLB_SYSTEM_WINDOWS
     #define strtok_r(str, delimiter, context) \
@@ -151,7 +152,7 @@ int tls_context_alpn_set(void *ctx_backend, const char *alpn)
     result = 0;
 
     if (alpn != NULL) {
-        wire_format_alpn = flb_calloc(strlen(alpn), 
+        wire_format_alpn = flb_calloc(strlen(alpn),
                                       sizeof(char) + 1);
 
         if (wire_format_alpn == NULL) {
@@ -162,15 +163,15 @@ int tls_context_alpn_set(void *ctx_backend, const char *alpn)
 
         if (alpn_working_copy == NULL) {
             flb_free(wire_format_alpn);
-            
+
             return -1;
         }
 
         wire_format_alpn_index = 1;
         alpn_token_context = NULL;
 
-        alpn_token = strtok_r(alpn_working_copy, 
-                              ",", 
+        alpn_token = strtok_r(alpn_working_copy,
+                              ",",
                               &alpn_token_context);
 
         while (alpn_token != NULL) {
@@ -182,8 +183,8 @@ int tls_context_alpn_set(void *ctx_backend, const char *alpn)
 
             wire_format_alpn_index += strlen(alpn_token) + 1;
 
-            alpn_token = strtok_r(NULL, 
-                                  ",", 
+            alpn_token = strtok_r(NULL,
+                                  ",",
                                   &alpn_token_context);
         }
 
@@ -219,8 +220,8 @@ static int tls_context_server_alpn_select_callback(SSL *ssl,
     if (ctx->alpn != NULL) {
         result = SSL_select_next_proto((unsigned char **) out,
                                        outlen,
-                                       &ctx->alpn[1], 
-                                       (unsigned int) ctx->alpn[0], 
+                                       (const unsigned char *) &ctx->alpn[1],
+                                       (unsigned int) ctx->alpn[0],
                                        in,
                                        inlen);
 
@@ -234,7 +235,7 @@ static int tls_context_server_alpn_select_callback(SSL *ssl,
 
     return result;
 }
-      
+
 #ifdef _MSC_VER
 static int windows_load_system_certificates(struct tls_context *ctx)
 {
@@ -304,7 +305,7 @@ static int load_system_certificates(struct tls_context *ctx)
     }
     return 0;
 }
-  
+
 static void *tls_context_create(int verify,
                                 int debug,
                                 int mode,
@@ -368,8 +369,8 @@ static void *tls_context_create(int verify,
     pthread_mutex_init(&ctx->mutex, NULL);
 
     if (mode == FLB_TLS_SERVER_MODE) {
-        SSL_CTX_set_alpn_select_cb(ssl_ctx, 
-                                   tls_context_server_alpn_select_callback, 
+        SSL_CTX_set_alpn_select_cb(ssl_ctx,
+                                   tls_context_server_alpn_select_callback,
                                    ctx);
     }
 
@@ -577,6 +578,8 @@ static int tls_net_write(struct flb_tls_session *session,
                          const void *data, size_t len)
 {
     int ret;
+    int ssl_ret;
+    int err_code;
     char err_buf[256];
     size_t total = 0;
     struct tls_context *ctx;
@@ -600,18 +603,28 @@ static int tls_net_write(struct flb_tls_session *session,
                     len - total);
 
     if (ret <= 0) {
-        ret = SSL_get_error(backend_session->ssl, ret);
+        ssl_ret = SSL_get_error(backend_session->ssl, ret);
 
-        if (ret == SSL_ERROR_WANT_WRITE) {
+        if (ssl_ret == SSL_ERROR_WANT_WRITE) {
             ret = FLB_TLS_WANT_WRITE;
         }
-        else if (ret == SSL_ERROR_WANT_READ) {
+        else if (ssl_ret == SSL_ERROR_WANT_READ) {
             ret = FLB_TLS_WANT_READ;
         }
-        else if (ret == SSL_ERROR_SYSCALL) {
-            flb_errno();
-            ERR_error_string_n(ret, err_buf, sizeof(err_buf)-1);
-            flb_error("[tls] syscall error: %s", err_buf);
+        else if (ssl_ret == SSL_ERROR_SYSCALL) {
+            if (ERR_get_error() == 0) {
+                if (ret == 0) {
+                    flb_debug("[tls] connection closed");
+                }
+                else {
+                    flb_error("[tls] syscall error: %s", strerror(errno));
+                }
+            }
+            else {
+                err_code = ERR_get_error();
+                ERR_error_string_n(err_code, err_buf, sizeof(err_buf) - 1);
+                flb_error("[tls] syscall error: %s", err_buf);
+            }
 
             /* According to the documentation these are non-recoverable
              * errors so we don't need to screen them before saving them
@@ -623,9 +636,14 @@ static int tls_net_write(struct flb_tls_session *session,
             ret = -1;
         }
         else {
-            ERR_error_string_n(ret, err_buf, sizeof(err_buf)-1);
-            flb_error("[tls] error: %s", err_buf);
-
+            err_code = ERR_get_error();
+            if (err_code == 0) {
+                flb_error("[tls] unknown error");
+            }
+            else {
+                ERR_error_string_n(err_code, err_buf, sizeof(err_buf) - 1);
+                flb_error("[tls] error: %s", err_buf);
+            }
             ret = -1;
         }
     }
@@ -636,11 +654,33 @@ static int tls_net_write(struct flb_tls_session *session,
     return ret;
 }
 
+int setup_hostname_validation(struct tls_session *session, const char *hostname)
+{
+    X509_VERIFY_PARAM *param;
+
+    param = SSL_get0_param(session->ssl);
+
+    if (!param) {
+        flb_error("[tls] error: ssl context is invalid");
+        return -1;
+    }
+
+    X509_VERIFY_PARAM_set_hostflags(param, X509_CHECK_FLAG_NO_PARTIAL_WILDCARDS);
+    if (!X509_VERIFY_PARAM_set1_host(param, hostname, 0)) {
+        flb_error("[tls] error: hostname parameter vailidation is failed : %s",
+                  hostname);
+        return -1;
+    }
+
+    return 0;
+}
+
 static int tls_net_handshake(struct flb_tls *tls,
                              char *vhost,
                              void *ptr_session)
 {
     int ret = 0;
+    long ssl_code = 0;
     char err_buf[256];
     struct tls_session *session = ptr_session;
     struct tls_context *ctx;
@@ -669,6 +709,21 @@ static int tls_net_handshake(struct flb_tls *tls,
         }
     }
 
+    if (tls->verify == FLB_TRUE &&
+        tls->verify_hostname == FLB_TRUE) {
+        if (vhost != NULL) {
+            ret = setup_hostname_validation(session, vhost);
+        }
+        else if (tls->vhost) {
+            ret = setup_hostname_validation(session, tls->vhost);
+        }
+
+        if (ret != 0) {
+            pthread_mutex_unlock(&ctx->mutex);
+            return -1;
+        }
+    }
+
     ERR_clear_error();
 
     if (tls->mode == FLB_TLS_CLIENT_MODE) {
@@ -686,7 +741,14 @@ static int tls_net_handshake(struct flb_tls *tls,
             // The SSL_ERROR_SYSCALL with errno value of 0 indicates unexpected
             //  EOF from the peer. This is fixed in OpenSSL 3.0.
             if (ret == 0) {
-            	flb_error("[tls] error: unexpected EOF");
+                ssl_code = SSL_get_verify_result(session->ssl);
+                if (ssl_code != X509_V_OK) {
+                    flb_error("[tls] error: unexpected EOF with reason: %s",
+                              ERR_reason_error_string(ERR_get_error()));
+                }
+                else {
+                    flb_error("[tls] error: unexpected EOF");
+                }
             } else {
                 ERR_error_string_n(ret, err_buf, sizeof(err_buf)-1);
                 flb_error("[tls] error: %s", err_buf);
